@@ -1,8 +1,9 @@
 from arkitekt.apps.mikro import MikroApp
 from arkitekt.apps.rekuest import RekuestApp
+from arkitekt.apps.unlok import UnlokApp
 
 
-class ConnectedApp(MikroApp, RekuestApp):
+class ConnectedApp(MikroApp, RekuestApp, UnlokApp):
     pass
 
 
