@@ -1,20 +1,29 @@
 import argparse
-from enum import Enum
+import asyncio
+import os
 import sys
+from enum import Enum
+
+from rich.console import Console
+from rich.prompt import Confirm, Prompt
+from rich.table import Table
+
 from arkitekt.apps.connected import App
 from arkitekt.cli.prod.check import check_app, check_app_loop, check_fakts_loop
+from arkitekt.cli.prod.dump import import_directory_and_dump
 from arkitekt.cli.prod.run import import_directory_and_start
 from fakts import Fakts
-from fakts.discovery.static import StaticDiscovery
-from herre import Herre
-from rich.console import Console
-from rich.prompt import Prompt, Confirm
-from rich.table import Table
-import os
-import asyncio
-from fakts.grants.remote.device_code import DeviceCodeGrant
 from fakts.discovery.advertised import AdvertisedDiscovery
-from fakts.grants.remote.claim import ClaimGrant
+from fakts.discovery.static import StaticDiscovery
+from fakts.grants.remote.device_code import DeviceCodeGrant
+from fakts.grants.remote.static import StaticGrant
+from herre import Herre
+from arkitekt.cli.logic.initialize import initialize_manifest
+from arkitekt.cli.logic.connect import connect
+from arkitekt.cli.logic.run import run
+from arkitekt.cli.logic.dev import dev
+import yaml
+
 
 try:
     from rich.traceback import install
@@ -28,13 +37,11 @@ directory = os.getcwd()
 
 class ArkitektOptions(str, Enum):
     INIT = "init"
-    DEV = "dev"
-    LOGOUT = "logout"
-    LOGIN = "login"
+    CONNECT = "connect"
     RUN = "run"
-    CHECK = "check"
-    CLAIM = "claim"
     WAIT = "wait"
+    DEV = "dev"
+    DUMP = "dump"
 
 
 class TemplateOptions(str, Enum):
@@ -102,8 +109,7 @@ def main(
     claim=False,
     silent=False,
     overwrite=False,
-    client_id=None,
-    client_secret=None,
+    token=None,
     endpoint_url=None,
     retries=3,
     interval=1,
@@ -122,10 +128,27 @@ def main(
             app_directory = os.path.join(os.getcwd(), path)
             name = name or path
 
-        fakts_path = os.path.join(app_directory, "fakts.yaml")
         run_script_path = os.path.join(app_directory, "run.py")
+        config_path = os.path.join(app_directory, ".arkitekt")
+
+        if script == ArkitektOptions.INIT:
+            initialize_manifest(app_directory=app_directory, silent=silent)
+            return
+
+        if script == ArkitektOptions.CONNECT:
+            connect(app_directory=app_directory, silent=silent)
+            return
+
+        if script == ArkitektOptions.RUN:
+            run(path=path, silent=silent)
+            return
+
+        if script == ArkitektOptions.DEV:
+            dev(path=path, silent=silent)
+            return
 
         if script == ArkitektOptions.WAIT:
+
             url = endpoint_url or (
                 Prompt.ask(
                     "Give us the path to your fakts instance",
@@ -174,6 +197,19 @@ def main(
 
             asyncio.run(import_directory_and_start(path, entrypoint="run"))
 
+        if script == ArkitektOptions.DUMP:
+
+            if not os.path.isfile(run_script_path):
+                console.print(
+                    f"Could't find a run.py in {app_directory} {run_script_path}"
+                )
+                return
+            if not os.path.isfile(fakts_path):
+                console.print(f"{app_directory} does not have a valid fakts.yaml")
+                return
+
+            asyncio.run(import_directory_and_dump(path, entrypoint="run"))
+
         if script == ArkitektOptions.CHECK:
 
             if not os.path.isfile(fakts_path):
@@ -239,6 +275,36 @@ def main(
 
                 console.print(f"Initializing a new Configuration for {name}")
 
+                app_identifier = (
+                    name if silent else Prompt.ask("Give your app a unique identifier")
+                )
+                app_version = (
+                    "0.0.1" if silent else Prompt.ask("Give your app a version")
+                )
+                app_description = (
+                    "A new app" if silent else Prompt.ask("Give your app a description")
+                )
+
+                console.log("Which scopes do you want your app to have?")
+                scopes = []
+                for scope in available_scopes:
+                    if Confirm.ask(f"App should have {scope} scope?"):
+                        scopes.append(scope)
+
+                if not scopes:
+                    console.print("App needs at least one scope")
+                    return
+
+                manifest = {
+                    "identifier": app_identifier,
+                    "version": app_version,
+                    "description": app_description,
+                    "scopes": scopes,
+                }
+
+                with open(fakts_path, "w") as f:
+                    yaml.dump(manifest, f)
+
                 if scan_network is None:
                     scan_network = (
                         Confirm.ask(
@@ -357,20 +423,15 @@ def entrypoint():
         "--template", type=TemplateOptions, help="The run script template"
     )
     parser.add_argument(
-        "--client_id",
+        "--token",
         type=str,
-        help="The client id (only to be used together with claim grant",
+        help="The token to negoatite the connection",
     )
     parser.add_argument(
         "--endpoint_url",
         type=str,
         help="The endpoint url for the fakts instance",
     )
-    parser.add_argument(
-        "--client_secret",
-        type=str,
-        help="The client secret (only to be used together with claim grant",
-    )
     parser.add_argument(
         "--grant", type=GrantOptions, help="The grant to use", default="device"
     )
@@ -397,8 +458,7 @@ def entrypoint():
         template=args.template,
         services=args.services.split(",") if args.services else [],
         silent=args.silent,
-        client_id=args.client_id,
-        client_secret=args.client_secret,
+        token=args.token,
         endpoint_url=args.endpoint_url,
         grant=args.grant,
         retries=args.retries,
