@@ -4,6 +4,8 @@ import sys
 import os
 from arkitekt.apps.fakts import ArkitektFakts
 from fakts import Fakts
+from fakts.grants.remote.static import StaticGrant
+from fakts.discovery.static import StaticDiscovery
 from rich.console import Console
 from arkitekt import Arkitekt
 
@@ -30,14 +32,23 @@ class Run:
         self.module = import_module(self.module_path)
         os.environ["ARKITEKT_AGENT_DEBUG"] = "False"
 
-    async def run(self):
+    async def run(self, token=None, endpoint=None):
 
-        app = Arkitekt(fakts=ArkitektFakts(fakts_path=f"{self.watch_path}/fakts.yaml"))
+        app = Arkitekt(
+            fakts=ArkitektFakts(
+                grant=StaticGrant(
+                    discovery=StaticDiscovery(
+                        base_url=endpoint or os.getenv("FAKTS_ENDPOINT_URL")
+                    ),
+                    token=token or os.getenv("FAKTS_TOKEN"),
+                )
+            )
+        )
 
         async with app:
             await app.rekuest.run()
 
 
-async def import_directory_and_start(path="watch", entrypoint="run"):
+async def import_directory_and_start(path, token=None, endpoint=None):
     host = Run(path=path)
-    await host.run()
+    await host.run(token=token, endpoint=endpoint)
